/**	\file Element.h
 **	\date  2008-05-26
 **	\author grymse@alhem.net
**/
/*
Copyright (C) 2008-2009  Anders Hedstrom

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#ifndef _Element_H
#define _Element_H

#include <string>
#include <list>
#include "TypeBase.h"


class Wsdl;
class Application;

class Element : public TypeBase
{
public:
	Element(const Wsdl& wsdl, const XmlNode& node, bool in_sequence, bool in_choice, const std::string& name = "", const std::string& ns_prefix = "");
	~Element();

	const std::string& Name() const { return m_name; }
	const std::string& BaseType() const { return m_base_type; }
	const std::string Documentation() const;

	void CreateInterface(FILE *fil) const;

	bool IsOptional() const { return m_minOccurs == 0; }
	bool IsVector() const { return m_maxOccurs > 1 || m_maxOccurs == -1; }

	const std::string CName() const;
	const std::string CName1up() const;

	const std::string CType_decl() const;
	const std::string CType_in() const;
	const std::string CType_out() const;
	/** c type default value */
	const std::string DefaultValue() const;
	/** default value from xml document */
	const std::string& Default() const;

	bool HasDefault() const;
	bool IsComplexType() const;
	bool IsSimpleType() const;

private:
	Application& m_appl;
	std::string m_name;
	std::string m_base_type;
	int m_minOccurs;
	int m_maxOccurs;
	bool m_has_default;
	std::string m_default;
};




#endif // _Element_H
